# Installation

## Stable release

```{include} ../README.md
:start-after: <!-- start-installation -->
:end-before: <!-- end-installation -->
```

This is the preferred method to install `uv-workon`, as it will always install
the most recent stable release.

## From sources

See [](./contributing) for details on installing from source.
